@@ -10,7 +10,7 @@ class AssetExecutor:
     """Class representing the call to the Gateway execute endpoint."""
 
     @staticmethod
-    def execute(agreement_id, compute_ddo, workflow_ddo, consumer_account, gateway, index):
+    def execute(agreement_id, compute_ddo, workflow_ddo, consumer_account, gateway, index, config):
         """
 
         :param agreement_id:
@@ -22,6 +22,6 @@ class AssetExecutor:
         service_endpoint = ServiceAgreement.from_ddo(ServiceTypes.CLOUD_COMPUTE,
                                                      compute_ddo).service_endpoint
         response = gateway.execute_compute_service(agreement_id, service_endpoint,
-                                                   consumer_account, workflow_ddo)
+                                                   consumer_account, workflow_ddo, config)
 
         return response.json()["workflowId"]
